bayespy.inference.vmp.nodes.stochastic.Stochastic.__init__
==========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.__init__